@@ -6,6 +6,7 @@ import copy
 import re
 
 import numpy as np
+import h5py
 
 from damask_parse.rotation import rot_mat2euler, euler2rot_mat_n
 
@@ -345,3 +346,44 @@ def align_orientations(ori, orientation_coordinate_system, model_coordinate_syst
             raise NotImplementedError(msg)
 
     print(f'New Euler angles:\n{ori}')
+
+
+def get_HDF5_incremental_quantity(hdf5_path, dat_path, transforms=None, increments=1):
+    """Accessing HDF5 file directly, extract data defined at each increment.
+
+    Parameters
+    ----------
+    hdf5_path : Path or str
+        Path to the HDF5 file generated by DAMASK
+    dat_path : str
+        Forward slash delimeted str path within the DAMASK HDF5 file of the incremental
+        data to extract. This path must exist within each `incrementXXXXX` group in the
+        file. Example: "constituent/1_Al/generic/epsilon_V^0(Fp)_vM".
+    transforms : list of dict, optional
+        List of manipulations to perform on the data. Each dict may have one or more of
+        the following keys:
+            mean_along_axes : int or list of int, optional
+                This uses `numpy.mean` on the data. Note that the zeroth axis is the
+                increment axis!
+            sum_along_axes : int or list of int, optional
+                This uses `numpy.sum` on the data. Note that the zeroth axis is the
+                increment axis!
+    increments : int, optional
+        Increment step size. By default, 1, in which case data for every increment will
+        be extracted.
+
+    """
+
+    with h5py.File(str(hdf5_path), 'r') as f:
+
+        incs = [i for i in f.keys() if 'inc' in i]
+        data = np.array([f[i][dat_path][()] for i in incs])[::increments]
+
+        if transforms:
+            for i in transforms:
+                if 'mean_along_axes' in i:
+                    data = np.mean(data, i['mean_along_axes'])
+                if 'sum_along_axes' in i:
+                    data = np.sum(data, i['sum_along_axes'])
+
+        return data
